@@ -2,4 +2,7 @@
 
 __author__ = """James Irving"""
 __email__ = 'james.irving.phd@gmail.com'
-__version__ = '0.1.0'
+__version__ = '0.1.10'
+
+from .default import *
+# from .fsds import imports 
\ No newline at end of file
